#!/bin/bash

# PKGHOME: http://www.gnu.org/software/ddd
# SOURCE: ftp://ftp.gnu.org/gnu/ddd/ddd-3.3.11.tar.gz
# MAINTERNER: Peter Klimas <peter.klimas@gmail.com>
# FORMER MAINTAINER: fdeak <ferenc.deak@gmail.com>
# DEPENDS: lesstif freetype ncurses xorg zlib

soft='ddd'
softversion='3.3.11'
packageversion='52.2'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"
numjobs='-j2'

set -e
cd $buildir
rm -rf $src
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest

tar xzf $srcpkg
cd $src
chown -R root:root .
find . -perm 664 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

# Build & install the pkg
./configure --prefix=/usr
make $numjobs
make install DESTDIR=$dest
rm $dest//usr/share/ddd-$softversion/{COPYING,NEWS}
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
cp $buildir/ddd.png $dest/usr/share/icons/hicolor/48x48/apps/ddd.png

# Strip binaries and libraries
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress man pages
( cd $dest/usr/man
  find . -type f -exec gzip -9 {} \;
  for i in `find . -type l` ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
)

# Compress info pages and remove the package's dir file
rm -rf $dest/usr/info/dir
find $dest/usr/info -type f -exec gzip -9f {} \;

# Install docs
mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS COPYING* CREDITS NEWS PROBLEMS README TIPS TODO doc/ddd.pdf doc/ddd-paper.ps doc/html/ddd.html \
  $dest/usr/doc/$soft-$softversion

mkdir -p $dest/usr/share/applications
cat << "EOF" > $dest/usr/share/applications/$soft.desktop
[Desktop Entry]
Name=DDD Debugger
Comment=Data Display Debugger
Exec=ddd
Icon=ddd
Type=Application
Categories=Application;Development;Debugger;
Encoding=UTF-8
EOF

# Save the build script
mkdir -p $dest/usr/src/$soft-$softversion
( cd $buildir; cp -a build-$soft.sh $dest/usr/src/$soft-$softversion/ )

# Create the /install directory
mkdir -p $dest/install
cat > $dest/install/slack-desc << END
   |-----handy-ruler------------------------------------------------------|
ddd: ddd - graphical front-end for command-line debuggers
ddd: 
ddd: GNU DDD is a graphical front-end for command-line debuggers such as
ddd: GDB, DBX, WDB, Ladebug, JDB, XDB, the Perl debugger, the bash
ddd: debugger, or the Python debugger. Besides usual'' front-end features
ddd: such as viewing source texts, DDD has become famous through its
ddd: interactive graphical data display, where data structures are
ddd: displayed as graphs.
ddd: 
ddd: 
ddd: 
END

# Create the Zenwalk package
cd $dest
/sbin/makepkg -l y -c n $dest.tgz
(cd $buildir; md5sum $package.tgz > $package.md5)

